========
Radegast
========


.. image:: https://img.shields.io/pypi/v/radegast.svg
        :target: https://pypi.python.org/pypi/radegast

.. image:: https://img.shields.io/travis/dswistowski/radegast.svg
        :target: https://travis-ci.com/dswistowski/radegast

.. image:: https://readthedocs.org/projects/radegast/badge/?version=latest
        :target: https://radegast.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


TBD

Features
--------

TBD

Credits
-------

Some parts of this code, and concept borrowed from cattrs_ project

.. _Cattrs: https://github.com/Tinche/cattrs

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
